@@ -46,6 +46,7 @@
 #include "rb-debug.h"
 #include "rb-dialog.h"
 #include "rb-file-helpers.h"
+#include "rb-string-helpers.h"
 #include "rb-thread-helpers.h"
 #include "rb-stock-icons.h"
 #include "eel-gconf-extensions.h"
@@ -64,6 +65,7 @@ static gboolean dry_run		= FALSE;
 static gboolean print_playing = FALSE;
 static gboolean print_playing_path = FALSE;
 static gboolean playpause       = FALSE;
+static gboolean focus           = FALSE;
 static gboolean previous        = FALSE;
 static gboolean next            = FALSE;
 static gboolean print_play_time = FALSE;
@@ -88,6 +90,7 @@ main (int argc, char **argv)
         { "set-play-time", 	    0,  POPT_ARG_LONG,			&seek_time,				0, N_("Seek to the specified time in playing song if possible and exit"),	NULL },
         
 		{ "play-pause",		    0,  POPT_ARG_NONE,			&playpause,	        	0, N_("Toggle play/pause mode"),     NULL },
+		{ "focus",	    0,  POPT_ARG_NONE,			&focus,	        	0, N_("Focus the running player"),     NULL },
 		{ "previous",		    0,  POPT_ARG_NONE,			&previous,	        	0, N_("Jump to previous song"),     NULL },
 		{ "next",		        0,  POPT_ARG_NONE,			&next,		        	0, N_("Jump to next song"),     NULL },
 		
@@ -134,6 +137,7 @@ main (int argc, char **argv)
 		rb_debug_init (debug);
 
 	rb_file_helpers_init ();
+	rb_string_helpers_init ();
 
 	if (no_registration == FALSE && dry_run == FALSE) {
 		object = bonobo_activation_activate_from_id (RB_SHELL_OAFIID,
@@ -177,6 +181,7 @@ main (int argc, char **argv)
 	CORBA_exception_free (&ev);
 
 	rb_file_helpers_shutdown ();
+	rb_string_helpers_shutdown ();
 
 	monkey_media_shutdown ();
 
@@ -229,13 +234,12 @@ get_song_info (GNOME_Rhythmbox shell)
 {
 	Bonobo_PropertyBag pb;
 	CORBA_any *any;
-	GNOME_Rhythmbox_SongInfo *song_info;
+	GNOME_Rhythmbox_SongInfo *song_info = NULL;
 
 	pb = GNOME_Rhythmbox_getPlayerProperties (shell, &ev);
 	if (BONOBO_EX (&ev)) {
 		char *err = bonobo_exception_get_text (&ev);
 		g_warning (_("An exception occured '%s'"), err);
-		CORBA_free (pb);
 		return NULL;
 	}
 
@@ -246,7 +250,7 @@ get_song_info (GNOME_Rhythmbox shell)
 		char *err = bonobo_exception_get_text (&ev);
 		g_warning (_("An exception occured '%s'"), err);
 		g_free (err);
-		CORBA_free (pb);
+		bonobo_object_release_unref ((Bonobo_Unknown) pb, &ev);
 		return NULL;
 	}
 	
@@ -258,7 +262,7 @@ get_song_info (GNOME_Rhythmbox shell)
 		CORBA_free (any);
 	}
 
-	CORBA_free (pb);
+	bonobo_object_release_unref ((Bonobo_Unknown) pb, &ev);
 	return song_info;
 }
 
@@ -270,6 +274,14 @@ rb_handle_cmdline (char **argv, int argc,
 	int i;
 	gboolean grab_focus = TRUE;
 	
+	/*
+	 * All 'remote control' type actions should set grab_focus 
+	 * to false.  There are two ways to focus the window.  
+	 * Running 'rhythmbox' with no arguments when it is already
+	 * running.  Explicitly adding the --focus argument combined 
+	 * with other 'remote control' arguments.
+	 */
+
 	shell = bonobo_activation_activate_from_id (RB_SHELL_OAFIID, 0, NULL, &ev);
 	if (shell == NULL)
 	{
@@ -292,7 +304,6 @@ rb_handle_cmdline (char **argv, int argc,
 			CORBA_free (song_info);
 		}
 		grab_focus = FALSE;
-
 	}
 	
 	if (print_playing_path)
@@ -336,13 +347,22 @@ rb_handle_cmdline (char **argv, int argc,
 	}
 	
 	if (playpause)
+	{
 		GNOME_Rhythmbox_playPause (shell, &ev);
+		grab_focus = FALSE;
+	}
 
 	if (previous)
+	{
 		GNOME_Rhythmbox_previous (shell, &ev);
+		grab_focus = FALSE;
+	}
 
 	if (next)
+	{
 		GNOME_Rhythmbox_next (shell, &ev);
+		grab_focus = FALSE;
+	}
 
 	for (i = 1; i < argc; i++)
 	{
@@ -352,11 +372,10 @@ rb_handle_cmdline (char **argv, int argc,
 			
 		if (rb_uri_exists (tmp) == TRUE) {
 			GNOME_Rhythmbox_handleFile (shell, tmp, &ev);
-			grab_focus = TRUE;
 		}
 		
 		g_free (tmp);
-		
+		grab_focus = FALSE;
 	}
 	
 	if (quit == TRUE)
@@ -364,6 +383,13 @@ rb_handle_cmdline (char **argv, int argc,
 		GNOME_Rhythmbox_quit (shell, &ev);
 	}
 
+	if (focus)
+		grab_focus = TRUE;
+
+	if (already_running) {
+		gdk_notify_startup_complete ();
+	}
+
 	/* at the very least, we focus the window */
 	if (already_running == TRUE && grab_focus == TRUE)
 		GNOME_Rhythmbox_grabFocus (shell, &ev);
